# Combine the data from two data.frames

# Empty workspace
rm(list = ls(all = TRUE))
ls()

# Create dataframe with names (of genes) and their positions
Positions <- data.frame(Gene.ID = c("gene.1", "gene.2", "gene.3", "gene.4", "gene.5", "gene.6", "gene.7", "gene.8"), Gene.Position = c(1917, 1937, 1941, 1942, 1943, 1953, 1957, 1961), stringsAsFactors = FALSE)

# Create dataframe with gene expression data
Expression <- data.frame(Gene.ID = c("gene.3", "gene.2", "gene.5", "gene.7", "gene.9"), Gene.Expression = c(-2, 0.1, 3.5, 1.2, -0.4), stringsAsFactors = FALSE)


Positions
#  Gene.ID Gene.Position
#1  gene.1          1917
#2  gene.2          1937
#3  gene.3          1941
#4  gene.4          1942
#5  gene.5          1943
#6  gene.6          1953
#7  gene.7          1957
#8  gene.8          1961

Expression
#  Gene.ID Gene.Expression
#1  gene.3            -2.0
#2  gene.2             0.1
#3  gene.5             3.5
#4  gene.7             1.2
#5  gene.9            -0.4


?match

# Calculate matching gene.IDs
index <- match(Expression$Gene.ID, Positions$Gene.ID)
index
#  3  2  5  7 NA


abc <- merge(Positions, Expression, by = intersect("Gene.ID", "Gene.ID"), all.y = TRUE)
abc
#  Gene.ID Gene.Position Gene.Expression
#1  gene.2          1937             0.1
#2  gene.3          1941            -2.0
#3  gene.5          1943             3.5
#4  gene.7          1957             1.2
#5  gene.9            NA            -0.4

abc <- merge(Positions, Expression, by = intersect("Gene.ID", "Gene.ID"), all.x = TRUE, all.y = TRUE)
abc
#  Gene.ID Gene.Position Gene.Expression
#1  gene.1          1917              NA
#2  gene.2          1937             0.1
#3  gene.3          1941            -2.0
#4  gene.4          1942              NA
#5  gene.5          1943             3.5
#6  gene.6          1953              NA
#7  gene.7          1957             1.2
#8  gene.8          1961              NA
#9  gene.9            NA            -0.4

# Simultaneous removal of NAs by using "na.omit" function
abc <- na.omit(merge(Positions, Expression, by = intersect("Gene.ID", "Gene.ID"), all.x = TRUE, all.y = TRUE))
abc
#   Gene.ID Gene.Position Gene.Expression
# 2  gene.2          1937             0.1
# 3  gene.3          1941            -2.0
# 5  gene.5          1943             3.5
# 7  gene.7          1957             1.2

abc <- merge(Positions, Expression, by = intersect("Gene.ID", "Gene.ID"), all.x = TRUE)
abc
#  Gene.ID Gene.Position Gene.Expression
#1  gene.1          1917              NA
#2  gene.2          1937             0.1
#3  gene.3          1941            -2.0
#4  gene.4          1942              NA
#5  gene.5          1943             3.5
#6  gene.6          1953              NA
#7  gene.7          1957             1.2
#8  gene.8          1961              NA
 
