#===============================================================================

# Empty workspace and show all data objects
rm(list=ls(all=T));
ls(all=T);


## Calculation of overlap between Genes and Domains
## is based on the function "regionOverlap" from the package "Ringo".

## Here is an example of its usage:


# Essential (run once)!
## source("http://bioconductor.org/biocLite.R");
# Essential (run once)!
## biocLite("Ringo");
# http://www.bioconductor.org/packages/devel/bioc/html/Ringo.html


# EXAMPLE

library(Ringo);


Genes   <- data.frame(gene.ID=c("gene.1", "gene.2"), chr=c("chr1", "chr1"), start=c(100,510), end=c(200,520));
domains <- data.frame(domain.ID=c("domain.1","domain.2","domain.3","domain.4","domain.5"), chr=c("chr1","chr2","chr7","chr8","chr9"), start=c(500,100,50,80,100), end=c(700, 200, 250, 120,200));

Genes;
#   gene.ID  chr start end
# 1  gene.1 chr1   100 200
# 2  gene.2 chr1   510 520

domains;
#   domain.ID  chr start end
# 1  domain.1 chr1   500 700
# 2  domain.2 chr2   100 200
# 3  domain.3 chr7    50 250
# 4  domain.4 chr8    80 120
# 5  domain.5 chr9   100 200

?regionOverlap

regionOverlap(xdf=Genes, ydf=domains);
# 2 x 5 sparse Matrix of class "dgCMatrix"
#                
# [1,]  . . . . .
# [2,] 11 . . . .


outcome <- regionOverlap(xdf=Genes, ydf=domains);
outcome;
# 2 x 5 sparse Matrix of class "dgCMatrix"
#                
# [1,]  . . . . .
# [2,] 11 . . . .

str(outcome);
class(outcome);


outcome <- as.matrix(regionOverlap(xdf=Genes, ydf=domains));
outcome;
#      [,1] [,2] [,3] [,4] [,5]
# [1,]    0    0    0    0    0
# [2,]   11    0    0    0    0

str(outcome);
class(outcome);


outcome <- as.data.frame(as.matrix(regionOverlap(Genes, domains))); 
rownames(outcome) <- Genes$gene.ID; 
colnames(outcome) <- domains$domain.ID;
outcome;
#        domain.1 domain.2 domain.3 domain.4 domain.5
# gene.1        0        0        0        0        0
# gene.2       11        0        0        0        0


# if we are sure that each Gene overlap with no more than 1 domain
apply(outcome, 1, sum);
# [1]  0 11


Genes$overlap <- as.vector(apply(outcome, 1, sum))
Genes;
#   gene.ID  chr start end overlap
# 1  gene.1 chr1   100 200       0
# 2  gene.2 chr1   510 520      11


Genes$overlap <- apply(as.matrix(regionOverlap(xdf=Genes, ydf=domains)), 1, sum);
Genes;
#   gene.ID  chr start end overlap
# 1  gene.1 chr1   100 200       0
# 2  gene.2 chr1   510 520      11

#===============================================================================

# Overlap between Domains and Genes

# Empty workspace and show all data objects
rm(list=ls(all=T));
ls(all=T);

# Set "starting" directory (change accordingly)
setwd("D:/R/2014-12-09");

#-------------------------------------------------------------------------------
# Loading the list of Domains from the text file
Green.domains <- read.delim("Green_Domains.txt", header=T, as.is=T, dec=".");

# Checking "Green.domains"
dim(Green.domains);
# [1] 215   6

# Checking "Green.domains"
head(Green.domains);
#      UR green.domain  chr   start     end note
# 1 4D1-2            1 chrX 4610801 4612600    .
# 2 4D1-2            2 chrX 4623801 4624600    .
# 3 4D1-2            3 chrX 4655801 4656600    .
# 4 4D1-2            4 chrX 4671401 4672000    .
# 5 4D1-2            5 chrX 4686801 4690600    .
# 6 4D1-2            6 chrX 4699201 4700000    .

# Remove unimportant/useless columns
Green.domains <- Green.domains[,-c(1,6)];

head(Green.domains);
#   green.domain  chr   start     end
# 1            1 chrX 4610801 4612600
# 2            2 chrX 4623801 4624600
# 3            3 chrX 4655801 4656600
# 4            4 chrX 4671401 4672000
# 5            5 chrX 4686801 4690600
# 6            6 chrX 4699201 4700000


# Loading the list of Domains
Green.domains <- read.delim("Green_Domains.txt", header=T, as.is=T, dec=".");

#-------------------------------------------------------------------------------
# Loading the list of Genes from the text file
Genes <- read.delim("Genes.txt", header=T, as.is=T, dec=".");

# Checking "Genes"
dim(Genes);
# [1] 78  6

# Checking "Genes"
head(Genes);
#    chr   start     end strand     FBgn.ID gene.symbol
# 1 chrX 4601951 4623527      + FBgn0029723      Proc-R
# 2 chrX 4720007 4720866      + FBgn0029729     CG12682
# 3 chrX 4734990 4799908      + FBgn0260971     CG42594
# 4 chrX 7175122 7299830      - FBgn0029941      CG1677
# 5 chrX 7060484 7299830      - FBgn0265457     CR44357
# 6 chrX 7318560 7318875      - FBgn0040922     CG15036

#-------------------------------------------------------------------------------

# Load the package "Ringo"
library(Ringo);

# Calculate the overlap between Genes and domains
Genes$overlap <- apply(as.matrix(regionOverlap(Genes, Green.domains)), 1, sum);

head(Genes);
#    chr   start     end strand     FBgn.ID gene.symbol overlap
# 1 chrX 4601951 4623527      + FBgn0029723      Proc-R    1800
# 2 chrX 4720007 4720866      + FBgn0029729     CG12682     394
# 3 chrX 4734990 4799908      + FBgn0260971     CG42594    6800
# 4 chrX 7175122 7299830      - FBgn0029941      CG1677    2400
# 5 chrX 7060484 7299830      - FBgn0265457     CR44357    2400
# 6 chrX 7318560 7318875      - FBgn0040922     CG15036     316


# Save Results in a file
write.table(Genes, file="Results.txt", 
            sep="\t", row.names=F, col.names=T, quote=F, dec=".", append=F);


#-------------------------------------------------------------------------------

# Total overlap of Genes with Green Domains
sum(Genes[,7]);
# [1] 304561
sum(Genes$overlap);
# [1] 304561


# Total length of Green Domains
sum(Green.domains$end-Green.domains$start+1);
# [1] 509601

# Percentage of the Genes/Domains overlap
sum(Genes$overlap)/sum(Green.domains$end-Green.domains$start+1)*100;
# [1] 59.7646



Green.domains[Green.domains$UR=="4D1-2",];

unique(Green.domains$UR);
#  [1] "4D1-2"  "7B1-2"  "9A3"    "10A1-2" "10B1-2" "11A6-9" "11D1-2" "12E1-2" "12E8-9" "13B3-4" "19A1-4" "19E1-2"
# [13] "19E3-4"
 
sort(unique(Green.domains$UR));
#  [1] "10A1-2" "10B1-2" "11A6-9" "11D1-2" "12E1-2" "12E8-9" "13B3-4" "19A1-4" "19E1-2" "19E3-4" "4D1-2"  "7B1-2" 
# [13] "9A3"   

length(unique(Green.domains$UR));
# [1] 13


for (i in 1:length(unique(Green.domains$UR))){

  UR.region <- Green.domains[Green.domains$UR==Green.domains$UR[i],];
  print(UR.region$UR[1]);
  print(nrow(UR.region));

}


table(Green.domains$UR);
# 10A1-2 10B1-2 11A6-9 11D1-2 12E1-2 12E8-9 13B3-4 19A1-4 19E1-2 19E3-4  4D1-2  7B1-2    9A3 
#     21     11     35     10     20     20     12     12     10     21     12     21     10 

#-------------------------------------------------------------------------------

